@@ -541,7 +541,7 @@ class MQLInterface(BaseInterface):  # noqa: D
 
         # Unless we are requesting multiple metrics, include the post-processor required by the UI
         # so that users are able to visualize the results in the query logs
-        if len(metrics) > 1:
+        if len(metrics) > 1 or len(dimensions) > 1:
             time_series = False
             result_format = None
         else:
